@@ -1,4 +1,18 @@
-/* $VERSION = 0.2 */
+/*
+our $VERSION = '2.1';
+*/
+
+/* Here we have C++ code which calls OpenCV functions related
+   to decoding QR codes, reading and writing images etc.
+   This code must live in its own file, totally independent of
+   XS code. In this way we keep the namespaces happy and avoid
+   clashes with Perl's macros and OpenCV functions/macros.
+   This is a good practice when interfacing Perl with external
+   C/C++ libraries: keep the interface outside of the XS by
+   creating intermediate functions.
+   In XS call the intermediate functions.
+*/
+
 #include <iostream>
 #include <fstream>
 #include <chrono>
